@@ -2,6 +2,6 @@
 # | |  |   |
 # '_'  '   '--
 __title__ = "otl"
-__version__ = "0.0.8"
+__version__ = "1.0.3"
 __license__ = "MIT"
-__author__ = "xuyong-waqu,lixuguang-waqu"
+__author__ = "xuyong,lixuguang"
